@@ -10,7 +10,7 @@ class Config(BaseModel, extra=Extra.ignore):
     wordcloud_height: int = 1200
     wordcloud_background_color: str = "black"
     wordcloud_font_path: str = str(Path(__file__).parent / "SourceHanSans.otf")
-    wordcloud_stopwords_path: Path = Path(__file__).parent / "stopwords.txt"
+    wordcloud_stopwords_path: Optional[Path]
     wordcloud_userdict_path: Optional[Path]
     wordcloud_timezone: Optional[str]
 
